#
# spec file for package perl-DBD-mysql
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-DBD-mysql
%define cpan_name DBD-mysql
Summary:        MySQL driver for the Perl5 Database Interface (DBI)
License:        GPL-1.0-or-later OR Artistic-1.0
Group:          Development/Libraries/Perl
Version:        4.021
Release:        18.3.1
Url:            http://search.cpan.org/dist/DBD-mysql/
Source:         http://search.cpan.org/CPAN/authors/id/C/CA/CAPTTOFU/%{cpan_name}-%{version}.tar.gz
Patch1:         bnc658792_pod_name_install.diff
Patch2:         perl-DBD-mysql-CVE-2016-1251.patch
Patch3:         perl-DBD-mysql-CVE-2016-1246.patch
Patch4:         perl-DBD-mysql-CVE-2016-1249.patch
Patch5:         perl-DBD-mysql-CVE-2017-10789.patch
# PATCH-FIX-UPSTREAM CVE-2017-10788 bsc#1047095 DoS or possibly RCE through use-after-free
Patch6:         perl-DBD-mysql-4.021-CVE-2017-10788.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# quilt does not grock that
%{perl_requires}
BuildRequires:  mysql-devel
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1.08
BuildRequires:  perl(Data::Dumper)
Requires:       perl(DBI) >= 1.08
Requires:       perl(Data::Dumper)

%description
DBD::mysql is the Perl5 Database Interface driver for the MySQL database.
In other words: DBD::mysql is an interface between the Perl programming
language and the MySQL programming API that comes with the MySQL relational
database management system. Most functions provided by this programming API
are supported. Some rarely used functions are missing, mainly because noone
ever requested them. :-)

%prep
%setup -q -n %{cpan_name}-%{version}
# rpmlint: executable-docs,
#  spurious-executable-perm
#  script-without-shebang
find -type f -exec %{__chmod} 0644 {} \;
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor --cflags="-I%{_includedir}/mysql $RPM_OPT_FLAGS"

%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%clean
%{__rm} -rf $RPM_BUILD_ROOT

%files -f %{name}.files
%defattr(-,root,root,-)
%doc ChangeLog eg INSTALL.html README TODO

%changelog
* Tue Apr 24 2018 pmonrealgonzalez@suse.com
- Add patch to fix CVE-2017-10788 bsc#1047095
  * Denial of service or possibly RCE through use-after-free
  * perl-DBD-mysql-4.021-CVE-2017-10788.patch
* Wed Apr 19 2017 sflees@suse.de
- Add patches to fix CVE-2017-10789 bsc#1047059
  * perl-DBD-mysql-CVE-2017-10789.patch
* Tue Jan  3 2017 tchvatal@suse.com
- Add patches to fix CVE-2016-1246 bsc#1002626 CVE-2016-1249 bsc#1010457
  * perl-DBD-mysql-CVE-2016-1246.patch
  * perl-DBD-mysql-CVE-2016-1249.patch
* Wed Nov 30 2016 tchvatal@suse.com
- Add patch to fix CVE-2016-1251 bsc#1012546 Fix use-after-free for repeated
  fetchrow_arrayref calls when mysql_server_prepare=1
  * perl-DBD-mysql-CVE-2016-1251.patch
* Sat Apr 28 2012 pascal.bleser@opensuse.org
- update to 4.021:
  * fix to enable PERL_NO_GET_CONTEXT to spee up DBD on thread Perls
  * fix to is_prefix not being exported by mysql
  * eliminate DBIS usage
  * enhanced/fixed server side prepared statement checks
  * fix missprint in doc of DBD::mysql of mysql_bind_type_guessing
  * misprint in lib/DBD/mysql.pm
* Mon Aug 29 2011 vcizek@suse.com
- update to 4.020
  * Numerous (!! Thank you!!) fixes for prepared statements
  - Chop blanks fixed
  - UTF8 improvements
  - fixed memory allocation for BLOBs
  - auto-reconnect
  * Fix in leak test, which failed sometime due to first assignment $prev_size over
  paging (Masahiro Chiba)
  * Catalog test allows use of schemas other than 'test' (Masahiro Chiba)
  * Documentation fix for auto_reconnect (Karen Etheridge <ether at cpan dot
  org>)
  * Win32 and general installation fixes (Alexandr Ciornii, http://chorny.net)
* Mon May  9 2011 pascal.bleser@opensuse.org
- update to 4.019:
  * asynchronous support
  * fix to change sv_undef to PL_sv_undef from 4.018
* Fri Jan  7 2011 vcizek@novell.com
- update to 4.018
- added bnc658792_pod_name_install.diff to fix BNC#658792
    upstreamed as https://rt.cpan.org/Ticket/Display.html?id=64013
  * Added client and server info patch from Robert M. Jansen
  * Added documentation and tests for new features
  * More code cleanup
* Fri Dec 17 2010 jw@novell.com
- added bnc658792_pod_name_install.diff to fix BNC#658792
  upstreamed as https://rt.cpan.org/Ticket/Display.html?id=64013
- updated to 4.018
  * Added client and server info patch from Robert M. Jansen
  * Added documentation and tests for new features
  * More code cleanup
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Aug 23 2010 anicka@suse.cz
- update to 4.017
  * BUG #60085, Andreas Koenig's patch for DBI changes
  * Updated documents
* Fri Jul 16 2010 chris@computersalat.de
- update to 4.016
  * Disabled mysql_bind_type_guessing due to one performance issue
    querying on a indexed character column unquoted will mean the index
    is not used
  * Fixed int types that should be bools
- 2010-07-09 Patrick Galbraith <patg@patg.net> (4.015)
  * BUG #56664 fixed t/40blobs.t skip_all logic (W. Phillip Moore)
  * BUG #57253 Fixed iteration past end of string (crash). (Chris Butler)
  * Added a new parameter for old behavior- mysql_bind_comment_placeholders which
    will make it possible to have placeholders bound for those who really
    want that behavior.
  * Fixed bind_type_guessing - always on now
- recreated by cpanspec 1.78
* Fri Apr 16 2010 chris@computersalat.de
- update to 4.014
  * BUG 30033 Fixed handling of comments to allow comments that
    contain characters that might otherwise cause placeholder
    detection to not work properly
  * BUG 53844, Fix for memory leak in stats. (Gregory Burmistrov)
  * BUG 49719, Fix for handling of NULLs in prepared statements
    (Gert Pache)
  * BUG 55627, Fix for testing failure due to strict mode (Yves)
  * BUG 51784, Fix for mysqladmin on Windows in Makefile
    (Zeeshan Muhammad)
  * BUG 41630, Typo in Makefile
  * Had to define true and false in dbdimp.h. Didn't work out of
    the box on Linux
- cleanup spec
  * recreated with cpanspec
  * disabled old Provides/Obsoletes
    mysqperl perl-Msql-Mysql-modules
  * added eg to doc
- rpmlint
  * file permission
    o chmod a-x on several files
* Fri Jan 15 2010 anicka@suse.cz
- update to 4.013
  * #49484: PATCH add support for MYSQL_INIT_COMMAND to
  DBD::mysql - Thanks Peter John Edwards ?
  * #48242: 'mysql_bind_type_guessing' doesn't work correctly
  with minus sign - Thanks Serguei Trouchelle!
  * #45616: t/40blobs.t cannot pass without database access -
  ServerError() not declared
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 4.012
  * Patch to bind_type_guessing from Craigslist,
  Thanks to Chris! Happiness is no quoted numbers.
  Fixed ChopBlanks to work with bind_type_guessing
  * Patch for win32 strawberry build
  Thanks to Curtis Jewell! Windows needs love
  * Patch for auto-reconnect to set active flag
  Thanks to Doug Fischer!
  * Fixed bug 32464 http://bugs.mysql.com/bug.php?id=32464.
  See https://rt.cpan.org/Ticket/Display.html?id=46308
  Add connection flag mysql_no_autocommit_cmd which users of
  MySQL Proxy can use to prevent 'set autocommit=#' from being
  issued by the driver. 'perldoc DBD::mysql' to see how to use
  this new flag
  * Added bind-type-guessing options to Makefile.PL so the entire
  test suite can be run with bind_type_guessing set.
* Tue Apr 14 2009 anicka@suse.cz
- update to 4.011
  * Renamed unsafe_bind_type_guessing, fixed some of the logic.
  * Fix issue of binding sever side integer parameters (server-side
  prepare statements) resulting in corrupt data
  * Updated documentation, cruft cleanup (as always)
* Tue Jan 20 2009 anicka@suse.cz
- update to 4.010
  * Fix to dbd_bind_ph() for uninitialized value 'buffer_length'
  * Fix to re-enable TAKE_IMP_DATA_VERSION. Still have to ensure DBI
  version 1.607 or higher
  * Fix to escaped single quotes throwing off bind param detection.
* Wed Sep 10 2008 anicka@suse.cz
- update to 4.008
  * Multi statement patch
  * Disabled TAKE_IMP_DATA_VERSION because segfault with DBI < 1.607
  * #29528: bind_param(..., SQL_FLOAT) ignores exponents - fixed
  * Cleanups to make mysqlEmb work under Cygwin
  * Modified and disabled tests for MySQL version < 4.1
  for unsupported features
* Thu Jun 19 2008 anicka@suse.cz
- update to 4.007
  * Took out mysql_server_init call where not needed
  * Complete re-write of test suit to use Test::More -
  tons of cleanups!
  * Makefile.PL changes to use current user in 'make test' if
  not defined
* Fri Jan  4 2008 anicka@suse.cz
- update to 4.006
  * Cleanups on OS X compile
  * Fixes to syntax errors on AIX
  * Removed test code that was leaving trace files around
* Mon Jun 11 2007 anicka@suse.cz
- update to 4.005
  * Replaced all references to dbis to use imp_xxh
    per DBI best practices
  * Fix to dbd_st_destroy
  * Removed all 'FindNewTable' calls in all tests.
  * Better 'skip test' logic in some tests that were still
    running when they shouldn't have been.
- fix permissions of various files
* Fri Mar 30 2007 anicka@suse.cz
- update to 4.004
  * Work around a bug in old 3.23 servers by specifying NOT NULL
  for fields used as a primary key in tests.
  * Add support for mysql_warning_count statement handle attribute.
  * Add support for mysql_multi_statements connection option.
  * UTF8-Flag not set with flag mysql_enable_utf8 and column
  collation utf8_bin patch,
  * Fixed do_error definition
  * Conversion of test suite to Test::More
  * Fix inclusion of non-primary keys in primary_key_info.
* Fri Mar  2 2007 anicka@suse.cz
- update to 4.002
  * Rewrote table_info method to support all arguments
  * Add mysql_is_auto_increment to results of column_info().
  * Add implementation of foreign_key_info()
  * bugfixes
* Tue Jan  9 2007 anicka@suse.cz
- update to 4.001
  * Fix handling of unsigned integer values in result sets when
    using server-side prepared statements.
  * Do not tell Perl that the contents of binary fields are UTF-8.
  * Fix double-free of bound parameters when freeing statements.
  * Make sure to handle "magical" values in a couple of places.
  * Update the hints about what to do when zlib is found missing
    while linking.
  * Explicitly initialize the MySQL client library to avoid
    possible race conditions in a multithreaded application.
  * Fix warning when no connection attributes are passed
    to the connect method.
  * Removed redundant warnings when commit or rollback
    is called while AutoCommit is enabled.
  * Report correct type for decimal columns from MySQL 5.0 and later
  * Fix t/40bindparam.t to work when ANSI_QUOTES SQL_MODE is set.
  * Return a statement handle with an error when column_info is
    called on a table that does not exist.
  * Fix handling of table names with characters that did not
    match /\w/ in the column_info method.
  * Fix handling of negative integers bound to a column marked
    as SQL_INTEGER.
  * Add support for the primary_key_info method.
  * Fixed Bundle::DBD::mysql to only include modules required
    for using DBD::mysql, not the old Mysql package.
  * Updated Makefile.PL to not include files in .svn directories
  * Fixed various compile warnings in mysql.xs (ISO C)
  * Cleaned up stored procedure examples, made strict
  * Fixed bug that blew away subsequent result sets if you
    fetched all rows, only in result sets that had more
    than one row.
  * Added test for bug #14979
    http://rt.cpan.org/Ticket/Display.html?id=14979
  * Tested with ALL mysql versions, fixed 40types, 40bind_param
    tests to work with 4.0, 4.1
  * Fixed dbdimp.c to not test for MYSQL_DATA_TRUNCATED
    unless >= mysql 5.0
* Tue Jan  2 2007 anicka@suse.cz
- update to 4.00
  * fixed varying number of columns in multiple result sets
  * reworked patch for sqlstate
  * cleaned up much code that failed between versions
  * Tested this with 5.1, 5.0, 4.1, 4.0.
  * added fbind and bind alloc to dbd_st_describe. This was
    causing a crash when using with mod_perl
* Thu Oct 19 2006 anicka@suse.cz
- update to 3.0008
  * Added multiple fixes to dbd_st_prepare which fixed variable
  overwrite and unset increment counter. Also improved loop which
  checks statements for presence of "LIMIT" by using a pointer
  as opposed to char array increment variable.
  * Fixed declaration of "row" in mysql_st_internal_execute
  which caused compile errors on some platforms
  * Fixed casting of num_params to unsigned int in calls to NewZ
  in mysql.xs
* Wed Sep 13 2006 anicka@suse.cz
- update to 3.0007
  * bugfixes
  * Cleaned up tests to make sure test table is dropped
    at end of test.
* Thu Jul 13 2006 anicka@suse.cz
- update to 3.0006
  * many bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Jul 29 2005 mjancar@suse.cz
- update to 3.0002
* Thu Aug 19 2004 mjancar@suse.cz
- update to 2.9004
* Wed Mar 31 2004 kukuk@suse.de
- Replace perl-Msql-Mysql-modules
* Mon Mar  8 2004 mjancar@suse.cz
- new package to replace perl-Msql-Mysql-modules
